import React from 'react';
import { Button } from 'antd';

class CanvasMenu extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      dragging: false,
      pos: { x: 0, y: 0 },
      rel: null
    };
  }

  componentDidMount() {
    const x = (document.body.clientWidth - 219.594) / 2;
    const y = (document.body.clientHeight - 64) / 2;
    this.setState({ pos: { x, y } });
  }

  onMouseDown = event => {
    event.stopPropagation();
    event.preventDefault();

    // only left mouse button
    if (event.button !== 0) return;

    this.setState({
      dragging: true,
      rel: {
        x: event.pageX - this.state.pos.x,
        y: event.pageY - this.state.pos.y
      }
    });
  };

  onMouseUp = event => {
    event.stopPropagation();
    event.preventDefault();

    this.setState({ dragging: false });
  };

  onMouseMove = event => {
    if (!this.state.dragging) return;

    event.stopPropagation();
    event.preventDefault();

    // only left mouse button
    if (event.button !== 0) return;

    this.setState({
      pos: {
        x: event.pageX - this.state.rel.x,
        y: event.pageY - this.state.rel.y
      }
    });
  };

  render() {
    const { isCanvasActive, onDone } = this.props;
    const { pos } = this.state;

    if (!isCanvasActive) return null;

    return (
      <div
        style={{
          display: 'block',
          position: 'fixed',
          top: pos.y,
          left: pos.x,
          background: 'white',
          paddingLeft: 8,
          paddingRight: 8,
          borderWidth: 1,
          borderStyle: 'solid',
          cursor: 'grab',
          zIndex: 10
        }}
        onMouseDown={this.onMouseDown}
        onMouseUp={this.onMouseUp}
        onMouseMove={this.onMouseMove}
      >
        <p style={{ display: 'inline' }}>Information markieren</p>
        {/* <Icon
          style={{
            paddingLeft: 8,
            fontSize: '24px',
            color: 'black',
            cursor: 'pointer'
          }}
          type="rollback"
          onClick={onRollback}
        /> */}
        <Button
          style={{
            display: 'inline',
            marginLeft: 8
          }}
          type="primary"
          onClick={onDone}
        >
          Fertig
        </Button>
      </div>
    );
  }
}

export default CanvasMenu;
